// $BACKGROUND$
// this command makes the script working in background, 
//other actions can be performed in DigitalMicrograph while running the script

// temDM Scripting Example

/* CORRECT STAGE DRIFT*/
/* periodic compensation of the stage drift by stage shift or by image shift */

//rotate Decart coordinates 
void RotateDecartCoordinates(number alpha,number &x,number &y)
//alpha(rad) is counted COUNTCLOCKWISE
{
x=cos(alpha)*x+sin(alpha)*y
y=(-1)*sin(alpha)*x+cos(alpha)*y
}

//MAIN Script starts here

//finding the active camera, 
//prepare it for acquisition 
number CamID = CameraGetActiveCameraID()
CameraPrepareForAcquire(CamID)

//parameters
number Exposure = 0.05		//Exposure for  image tracking drift
number pause = 2			//pause among taking images
number maxCycles = 20		//after "maxCycles" tracking cycles the script stops
number binning = 4			//binning of camera pixels
number CameraWidth, CameraHeight //sizes of camera (unbinned)
number CalibrationStage = 1	//this value might differ from 1 unless the instrument is accurately calibrated 
number CalibrationImageShift = 1	//this value might differ from 1 unless the instrument is accurately calibrated 

//reading the camera size
CameraGetSize(CamID,CameraWidth, CameraHeight)

//acquisition of the reference image, reading the dimension calibration
image reference := CameraAcquire(CamID,Exposure,binning,binning)
//showimage(initial)
number scale = reference.ImageGetDimensionScale(0) 

//preparation of the image tracking drift  
image tracking := Imageclone(reference)	

//looping
number i
for(i=0;i<maxCycles;i++)
	{
	//looping can be stopped by pressing "alt" key
	if(OptionDown()==1) {result("\nscript halted by user");break;}

	//acquisition of the tracking image
	CameraAcquireInPlace(CamID,tracking,Exposure,binning,binning) 
	showimage(tracking)

	//cross correlating with initial image and extraction of the shift values
	image CrossCorellation = CrossCorrelate(tracking,reference) 
	number maxX,maxY
	max(CrossCorellation,maxX,maxY)
	number shiftX = (maxX - CameraWidth/binning/2)*scale
	number shiftY = -(maxY - CameraHeight/binning/2)*scale
	result("\ntracking "+i+" shiftX "+shiftX+"nm shiftY "+shiftY+"nm")

	//the (X,Y) coordinates in image shift may generally not coincide with 
	//the (X,Y) coordinates in the image.
	//they must be rotated at the predefined angle with the following subfunction.
	//There is, however, no such rotation in VirtualTEM, thus the angle = 0 
	RotateDecartCoordinates(0,shiftX,shiftY)
	
	//compensate shift
	EMChangeImageShift(-ShiftX*CalibrationImageShift,-ShiftY*CalibrationImageShift)

	result(" ... corrected")
	
	sleep(pause)
	}

//It is a good idea to reset image shift at the end.
EMsetImageShift(0,0)