// temDM Scripting Example

/* EFTEM ELEMENTAL MAPPING */
/* maps the intensity of the chosen EELS edge by three window method*/


//this function makes acquisition in one energy window
image OneWindowAcquisition(number CamID,number exposure,number Bin,number Eloss)
{
IFSetEnergyOffset(2,Eloss)

image im := CameraAcquire(CamID,exposure,Bin,Bin)

im.setName(Eloss+" eV")
//im.showimage()

return im
}

//this function maps a chosen edge
image MapElement(number CamID,string Element,number Eonset,number Ewidth,number Egap,number exposure,number Bin)
{
//set the energy slit width
IFSetSlitWidth(Ewidth)

//define energy steps
number Estep = Ewidth +Egap
number Estart = Eonset + Estep/2

//prepare images for three window acquisitions
image pre1,pre2,post
number Epre1,Epre2,Epost

//acquire three windows
for(number i=0;i<3;i++)
	{
	number Eloss = Estart-Estep*i
	image current:= OneWindowAcquisition(CamID,exposure,Bin,Eloss)
	if(i==0) {post:= current; Epost = Eloss;}
	if(i==1) {pre2:= current; Epre2 = Eloss;}
	if(i==2) {pre1:= current; Epre1 = Eloss;}
	}

//linear extrapolation of background
//(power law extrapolation is more accurate although require a bit more programming)
image background = pre2 - (pre1 - pre2)*(Epost -Epre2)/(Epre2 - Epre1)

//extract map
image map := Imageclone(post) 
map -= background
setName(map,Element)

return map
}

//MAIN SCRIPT STARTS HERE

//This simplest script does NOT involve the correction for the stage drift.
//In in-line system, one should wait sufficiently long to stabilize the stage.
//In virtual TEM, the following command cancls the stage drift:
ResetStageDrift112()
	
//the zero-loss peak must be aligned prior EFTEM. 
//In in-line system, one makes a manual or an automatic tune
//while in virtual TEM, the following command ensures the alignment:
ResetEnergy112()

// the rest commands are same for in-line and virtuasl TEM systems.
 	
//find and prepare the filter camera
number CamID = IFGetFilterCameraID()
CameraPrepareForAcquire(CamID)

//set the energy slit in
IFSetSlitIn(1)

//Elemental mapping
//input parameters: Element name,onset(eV),window width(eV),gap between windows(eV), exposure (s), binning
MapElement(CamID,"O",530,40,10,5,4).showimage()
MapElement(CamID,"Al",1560,40,10,20,4).showimage()

//remove the high tension offset,restore the reasonable energy slit	 
IFSetEnergyOffset(2,0)
IFSetSlitWidth(10)

//Finally you might discover that the virtual TEM uses 
//the example particle that is an Al core surrounded by the Al oxide !
