// $BACKGROUND$
// this command makes the script working in background, 
// other actions can be performed in DigitalMicrograph while running the script


// temDM Scripting Example

/* TRACK VARIATION OF PRIMARY ENERGY*/

//find and prepare the filter camera
number CamID = IFGetFilterCameraID()
CameraPrepareForAcquire(CamID)

//set spectroscopy mode if not active yet
IFSetSpectroscopyMode()

//parameters
number Exposure = 0.01		//Spectrum exposure 
number Cycles = 20			//number of measurements
number pause = 0.5			//pause among acquisitions in sec 

//get nessesary parameters
number ZoomChannel = IFGetSpectroscopyZoomChannel()
number top,left,bottom,right
IFGetDefaultSpectroscopyReadArea(top,left,bottom,right)
number Processing = CameraGetGainNormalizedEnum()
result("\ntop "+top +" left "+left+" bottom "+bottom+" right "+right)
number NumberDispersions = IFgetNumberOfDispersions() 
IFSetActiveDispersionIndex(NumberDispersions-1)	//choose the strongest dispersion
number dispersion = IFGetActiveDispersion()
result("\ndispersion "+dispersion+" processing "+processing)

//prepare the output image
image EnergyVariation := realimage("Energy",4,Cycles,1)

//get start time
number t0=GetOSTickCount()

//looping
number i
for(i=0;i<Cycles;i++)
	{
	//looping can be stopped by pressing "alt" key
	if(OptionDown()==1) {result("\nscript halted by user");break;}

	image im:= CameraAcquire(CamID,exposure,1,1,processing,top,left,bottom,right)
//showimage(im)             
	number maxX,maxY
	number maxIntensity = max(im,maxX,maxY)  
	number Energy = (maxX-ZoomChannel)*dispersion
	result("\n"+i+" maxIntensity "+maxIntensity+" maxX "+maxX+" maxY "+maxY+" Energy "+Energy)

	setPixel(EnergyVariation,i,0,Energy)
	
	sleep(pause)
	}

//get end time, calculate duration of cycle	
number dt = CalcOSSecondsBetween(t0,GetOSTickCount())
number CycleDuration = dt/Cycles

//calibrate and show the output image
ImageSetDimensionCalibration(EnergyVariation,0,0,CycleDuration,"sec",1)	
showimage(EnergyVariation)
